@@ -1,9 +1,10 @@
 from .splines import CubicSpline, CubicSplines
 from .multilinear import LinearSpline, LinearSplines
-from .eval_splines import options, eval_linear, eval_cubic
-from .prefilter_cubic import filter_cubic
+from .eval_splines import options, eval_linear, eval_cubic, eval_spline
+from .prefilter_cubic import filter_cubic, prefilter
 from .option_types import options as extrap_options
 
+
 # dummy functions
 def UCGrid(*args):
     return tuple(args)
